@@ -492,7 +492,7 @@ setMethod("Compare", c("POSIXt", "nanotime"),
 ##' @rdname nanotime
 setMethod("Compare", c("nanotime", "ANY"),
           function(e1, e2) {
-              if (class(e2) == "nanotime") {
+              if (inherits(e2, "nanotime")) {
                   e2 <- S3Part(e2, strictS3=TRUE)
               }
               callNextMethod(S3Part(e1, strictS3=TRUE), e2)
@@ -704,7 +704,7 @@ seq.nanotime <-
 	    stop("'by' must be specified if 'length.out' is NULL")
 	else { # dealing with 'by'
             if (length(by) != 1L) stop("'by' must be of length 1")
-            if (class(by) == "nanoperiod") {
+            if (inherits(by, "nanoperiod")) {
                 ## fish out the 'tz' parameter:
                 args <- list(...)
                 if (!any("tz" %in% names(args))) {
@@ -727,7 +727,7 @@ seq.nanotime <-
     }
     else if (missing(to) || is.null(to)) {
         if (length(by) != 1L) stop("'by' must be of length 1")
-        if (class(by) == "nanoperiod") {
+        if (inherits(by, "nanoperiod")) {
             ## fish out the 'tz' parameter:
             args <- list(...)
             if (!any("tz" %in% names(args))) {
@@ -784,8 +784,8 @@ setMethod("seq", c("nanotime"), seq.nanotime)
 all.equal.nanotime <- function(target, current, tolerance = sqrt(.Machine$double.eps), 
                                scale = NULL, countEQ = FALSE,
                                formatFUN = function(err, what) format(err), ..., check.attributes = TRUE) {
-    if (class(target)  == "nanotime") target  <- as.integer64(target)
-    if (class(current) == "nanotime") current <- as.integer64(current)
+    if (inherits(target, "nanotime")) target  <- as.integer64(target)
+    if (inherits(current, "nanotime")) current <- as.integer64(current)
     
     if (!is.numeric(tolerance)) 
         stop("'tolerance' should be numeric")
@@ -960,6 +960,7 @@ setMethod("nano_year", c("nanotime"), function(x, tz) nanotime_year_impl(x, tz))
 ##'     indicating the rounding precision
 ##' @param ... for future additional arguments
 ##' @examples
+##' \dontrun{
 ##' ## "classic" rounding:
 ##' nano_floor(as.nanotime("2010-10-10 11:12:15 UTC"), as.nanoduration("01:00:00"))
 ##' ## rounding with arbitrary precision:
@@ -970,7 +971,6 @@ setMethod("nano_year", c("nanotime"), function(x, tz) nanotime_year_impl(x, tz))
 ##' nano_ceiling(as.nanotime("2010-10-10 11:23:15 UTC"),
 ##'              as.nanoduration("01:15:23"),
 ##'              origin=as.nanotime("2010-10-10 11:23:15 UTC"))
-##' \dontrun{
 ##' ## using business concepts and rounding across a daylight saving change:
 ##' v <- seq(as.nanotime("2020-03-08 America/New_York"),
 ##'          by=as.nanoperiod("06:00:00"), length.out=8, tz="America/New_York")
@@ -1021,3 +1021,7 @@ setMethod("rep", c(x = "nanotime"), function(x, ...) {
     new("nanotime", callNextMethod())
 })
 
+##' @rdname nanotime
+as.character.nanotime <- function(x, ...) {
+    format(x, ...)
+}
