@@ -1,4 +1,5 @@
 #include <Rcpp.h>
+#include <RcppCCTZ_API.h>
 #include "nanotime/period.hpp"
 #include "nanotime/utilities.hpp"
 
@@ -6,20 +7,6 @@
 using namespace nanotime;
 
 
-// import function from 'RcppCCTZ':
-static inline duration getOffsetCnv(const dtime& dt, const std::string& z) {
-  typedef int GET_OFFSET_FUN(long long, const char*, int&); 
-  GET_OFFSET_FUN *getOffset = (GET_OFFSET_FUN *) R_GetCCallable("RcppCCTZ", "_RcppCCTZ_getOffset_nothrow" );
-
-  int offset;
-  int res = getOffset(std::chrono::duration_cast<std::chrono::seconds>(dt.time_since_epoch()).count(), z.c_str(), offset);
-  if (res < 0) {
-    Rcpp::stop("Cannot retrieve timezone '%s'.", z.c_str()); // ## nocov
-  }
-  return duration(offset).count() * std::chrono::seconds(1);
-}
-
-
 // C++-level floor and ceiling functions:
 
 // support for rounding 'dtime':
